commit-gnue
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

r5025 - in trunk: gnue-appserver gnue-common gnue-designer gnue-forms gn


From: jcater
Subject: r5025 - in trunk: gnue-appserver gnue-common gnue-designer gnue-forms gnue-navigator gnue-reports
Date: Tue, 6 Jan 2004 00:48:41 -0600 (CST)

Author: jcater
Date: 2004-01-06 00:48:39 -0600 (Tue, 06 Jan 2004)
New Revision: 5025

Modified:
   trunk/gnue-appserver/setup.py
   trunk/gnue-common/setup.py
   trunk/gnue-designer/setup.py
   trunk/gnue-forms/setup.py
   trunk/gnue-navigator/setup.py
   trunk/gnue-reports/setup.py
Log:
fixed install to ignore .svn instead of CVS/

Modified: trunk/gnue-appserver/setup.py
===================================================================
--- trunk/gnue-appserver/setup.py       2004-01-05 16:44:29 UTC (rev 5024)
+++ trunk/gnue-appserver/setup.py       2004-01-06 06:48:39 UTC (rev 5025)
@@ -82,8 +82,8 @@
 
   # ---------------------------------------------------------------------------
   # Build files to be distributed and installed:
-  # Should generate the files that go in a distribution but aren't in CVS.
-  # Gets called on sdist (always) and on build/install (only when run from 
CVS).
+  # Should generate the files that go in a distribution but aren't in SVN.
+  # Gets called on sdist (always) and on build/install (only when run from 
SVN).
   # ---------------------------------------------------------------------------
 
   def build_files (self):

Modified: trunk/gnue-common/setup.py
===================================================================
--- trunk/gnue-designer/setup.py        2004-01-05 16:44:29 UTC (rev 5024)
+++ trunk/gnue-designer/setup.py        2004-01-06 06:48:39 UTC (rev 5025)
@@ -74,8 +74,8 @@
 
   # ---------------------------------------------------------------------------
   # Build files to be distributed and installed:
-  # Should generate the files that go in a distribution but aren't in CVS.
-  # Gets called on sdist (always) and on build/install (only when run from 
CVS).
+  # Should generate the files that go in a distribution but aren't in SVN.
+  # Gets called on sdist (always) and on build/install (only when run from 
SVN).
   # ---------------------------------------------------------------------------
 
   def build_files (self):

Modified: trunk/gnue-forms/setup.py
===================================================================
--- trunk/gnue-forms/setup.py   2004-01-05 16:44:29 UTC (rev 5024)
+++ trunk/gnue-forms/setup.py   2004-01-06 06:48:39 UTC (rev 5025)
@@ -112,8 +112,8 @@
 
   # ---------------------------------------------------------------------------
   # Build files to be distributed and installed:
-  # Should generate the files that go in a distribution but aren't in CVS.
-  # Gets called on sdist (always) and on build/install (only when run from 
CVS).
+  # Should generate the files that go in a distribution but aren't in SVN.
+  # Gets called on sdist (always) and on build/install (only when run from 
SVN).
   # ---------------------------------------------------------------------------
 
   def build_files (self):

Modified: trunk/gnue-navigator/setup.py
===================================================================
--- trunk/gnue-navigator/setup.py       2004-01-05 16:44:29 UTC (rev 5024)
+++ trunk/gnue-navigator/setup.py       2004-01-06 06:48:39 UTC (rev 5025)
@@ -74,8 +74,8 @@
 
   # ---------------------------------------------------------------------------
   # Build files to be distributed and installed:
-  # Should generate the files that go in a distribution but aren't in CVS.
-  # Gets called on sdist (always) and on build/install (only when run from 
CVS).
+  # Should generate the files that go in a distribution but aren't in SVN.
+  # Gets called on sdist (always) and on build/install (only when run from 
SVN).
   # ---------------------------------------------------------------------------
 
   def build_files (self):

Modified: trunk/gnue-reports/setup.py
===================================================================
--- trunk/gnue-reports/setup.py 2004-01-05 16:44:29 UTC (rev 5024)
+++ trunk/gnue-reports/setup.py 2004-01-06 06:48:39 UTC (rev 5025)
@@ -93,8 +93,8 @@
 
   # ---------------------------------------------------------------------------
   # Build files to be distributed and installed:
-  # Should generate the files that go in a distribution but aren't in CVS.
-  # Gets called on sdist (always) and on build/install (only when run from 
CVS).
+  # Should generate the files that go in a distribution but aren't in SVN.
+  # Gets called on sdist (always) and on build/install (only when run from 
SVN).
   # ---------------------------------------------------------------------------
 
   def build_files (self):





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- trunk/gnue-common/setup.py  2004-01-05 16:44:29 UTC (rev 5024)
+++ trunk/gnue-common/setup.py  2004-01-06 06:48:39 UTC (rev 5025)
@@ -67,7 +67,7 @@
      Data_Files (base_dir = 'install_config',
                  copy_to = '',
                  template = ['recursive-include etc *',
-                             'prune etc/CVS'],
+                             'prune etc/.svn'],
                  preserve_path = 0),
      Data_Files (base_dir = 'install_data',
                  copy_to = 'share/locale',
@@ -81,7 +81,7 @@
      Data_Files (base_dir = 'install_data',
                  copy_to = 'share/doc/gnue-common',
                  template = ['recursive-include doc *',
-                             'prune doc/CVS',
+                             'prune doc/.svn',
                              'prune doc/man',
                              'prune doc/technotes'],
                  strip_dirs = 1, # This is a number, not true/false
@@ -89,8 +89,8 @@
 
 # -----------------------------------------------------------------------------
 # Build files to be distributed and installed:
 # Should generate the files that go in a distribution but aren't in CVS.
 # Gets called on sdist (always) and on build/install (only when run from CVS).
 # -----------------------------------------------------------------------------
 
 def build_files ():
@@ -187,13 +187,13 @@
     distutils.command.sdist.sdist.run (self)
 
 # =============================================================================
 # build: if done from CVS, build files to be installed first
 # =============================================================================
 
 class build (distutils.command.build.build):
 
   def run (self):
-    if not os.path.isfile ("PKG-INFO"):         # downloaded from CVS?
+    if not os.path.isfile ("PKG-INFO"):         # downloaded from SVN?
       build_files ()
     distutils.command.build.build.run (self)
 
@@ -89,8 +89,8 @@
 # -----------------------------------------------------------------------------
 # Build files to be distributed and installed:
-# Should generate the files that go in a distribution but aren't in CVS.
-# Gets called on sdist (always) and on build/install (only when run from CVS).
+# Should generate the files that go in a distribution but aren't in SVN.
+# Gets called on sdist (always) and on build/install (only when run from SVN).
 # -----------------------------------------------------------------------------
 
@@ -187,13 +187,13 @@
 
 # =============================================================================
-# build: if done from CVS, build files to be installed first
+# build: if done from SVN, build files to be installed first
 # =============================================================================
 

Modified: trunk/gnue-designer/setup.py
===================================================================